@@ -107,7 +107,16 @@ def get_logs(*, exam, email):
 
 
 @server_only
-def process_ok_exam_upload(*, exam, data, clear=True):
+@as_list
+def get_full_logs(*, exam, email):
+    db = SafeFirestore()
+
+    for ref in db.collection(exam).document(email).collection("history").stream():
+        yield ref.to_dict()
+
+
+@server_only
+def process_ok_exam_upload(*, exam, data, enable_clarifications=False, clear=True):
     """
     data: {
         "students": [
@@ -134,7 +143,9 @@ def process_ok_exam_upload(*, exam, data, clear=True):
     """
     db = SafeFirestore()
 
-    db.collection("exam-alerts").document(exam).set({"questions": data["questions"]})
+    db.collection("exam-alerts").document(exam).set(
+        {"questions": data["questions"], "enable_clarifications": enable_clarifications}
+    )
     ref = db.collection("exam-alerts").document(exam).collection("students")
     if clear:
         clear_collection(db, ref)
