@@ -1,5 +1,7 @@
 import random
 
+from examtool.api.utils import dict_to_list
+
 
 def scramble(email, exam, *, keep_data=False):
     random.seed(email)
@@ -151,6 +153,10 @@ def scramble(email, exam, *, keep_data=False):
     exam.pop("substitution_groups", None)
     exam.pop("substitutions_match", None)
 
+    exam["entropy"] = entropy = []
+    for _ in range(100):
+        entropy.append(random.randrange(1024))
+
     return exam
 
 
@@ -159,9 +165,10 @@ def get_elements(group):
 
 
 def select_substitutions(element):
-    substitutions = select_regular(element["substitutions"])
+    substitutions = select_regular(element.get("substitutions", {}))
     substitutions.update(select_no_replace(element.get("substitutions_match", [])))
     substitutions.update(select_group(element.get("substitution_groups", [])))
+    substitutions.update(select_ranges(element.get("substitution_ranges", {})))
     return substitutions
 
 
@@ -191,14 +198,23 @@ def select_group(substitution_groups):
     out = {}
     # DEFINE GROUP
     for blocks in substitution_groups:
-        k, *v = blocks
-        v = random.choice(v)
+        k = blocks["directives"]
+        v = dict_to_list(blocks["replacements"])
+        v = dict_to_list(random.choice(v))
         assert len(k) == len(v)
         for k0, v0 in zip(k, v):
             out[k0] = v0
     return out
 
 
+def select_ranges(substitution_ranges):
+    out = {}
+    # DEFINE RANGE
+    for k, [low, high] in sorted(substitution_ranges.items()):
+        out[k] = str(random.randrange(low, high))
+    return out
+
+
 def is_compressible_group(group):
     return (
         group.get("pick_some") == 1
